@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,24 +17,29 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-var checkboxLastInput;
+var checkbox_last_input;
 
-function checkbox (input, url) {
+function checkbox_v2 (input, val1, val2, val3 ) {
   // Store this input.
-  checkboxLastInput = input;
+  checkbox_last_input = input;
   // The URL where to POST to.
-  if (url === undefined) {
-    url = window.location.href.split("?")[0];
-    url = url.split('/').reverse()[0];
-  }
+  url = window.location.href.split("?")[0];
+  url = url.split('/').reverse()[0];
   // Post the checkbox state.
   $.ajax ({
     url: url,
     type: "POST",
-    data: { checkbox: input.name, checked: input.checked },
+    data: { checkbox: input.name, checked: input.checked, val1: val1, val2: val2, val3: val3 },
     error: function (jqXHR, textStatus, errorThrown) {
-      // Could not save: Revert the checkbox.
-      checkboxLastInput.checked = !checkboxLastInput.checked;
+      // Could not save: Revert the checkbox for consistency.
+      checkbox_last_input.checked = !checkbox_last_input.checked;
+    },
+    success: function (response) {
+      if (response == "reload") {
+        location.reload();
+      }
+    },
+    complete: function (xhr, status) {
     }
   });
 }
