@@ -21,7 +21,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include <config/libraries.h>
 
-string assets_external_url ();
-string assets_external (void * webserver_request);
+std::string assets_external_url ();
+std::string assets_external (void * webserver_request);
 
-string assets_external_logic_link_addon ();
+std::string assets_external_logic_link_addon ();
