@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,23 +17,16 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_ASSETS_PAGE_H
-#define INCLUDED_ASSETS_PAGE_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+namespace assets_page {
 
-class Assets_Page
-{
-public:
-  static string header (string title, void * webserver_request);
-  static string success (string message);
-  static string error (string message);
-  static string message (string message);
-  static string footer ();
-private:
-};
+std::string header (const std::string & title, void * webserver_request);
+std::string success (const std::string & message);
+std::string error (const std::string & message);
+std::string message (const std::string & message);
+std::string footer ();
 
-
-#endif
+}
