@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string changes_change_url ();
+std::string changes_change_url ();
 bool changes_change_acl (void * webserver_request);
-string changes_change (void * webserver_request);
+std::string changes_change (void * webserver_request);
