@@ -22,7 +22,17 @@
 #include <changes/statistics.h>
 #include <changes/manage.h>
 #include <tasks/logic.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#ifndef HAVE_PUGIXML
 #include <pugixml/pugixml.hpp>
+#endif
+#ifdef HAVE_PUGIXML
+#include <pugixml.hpp>
+#endif
+#pragma GCC diagnostic pop
 #include <locale/translate.h>
 #include <index/listing.h>
 #include <database/logs.h>
@@ -30,8 +40,7 @@
 #include <database/jobs.h>
 #include <filter/string.h>
 #include <webserver/request.h>
-
-
+using namespace std;
 using namespace pugi;
 
 
@@ -56,8 +65,8 @@ const char * changes_bible_category ()
 string changes_interlinks (void * webserver_request, string my_url)
 {
   // Storage the available links.
-  vector <string> urls;
-  vector <string> labels;
+  vector <string> urls {};
+  vector <string> labels {};
   
   // Handle situation that the user has permission to view the changes.
   if (changes_changes_acl (webserver_request)) {
@@ -97,8 +106,8 @@ string changes_interlinks (void * webserver_request, string my_url)
 #endif
 
   // Generate the links in XML.
-  xml_document document;
-  bool first = true;
+  xml_document document {};
+  bool first {true};
   for (unsigned int i = 0; i < urls.size (); i++) {
     if (!first) {
       xml_node node = document.append_child ("span");
@@ -112,7 +121,7 @@ string changes_interlinks (void * webserver_request, string my_url)
   }
   
   // Convert the document to a string.
-  stringstream output;
+  stringstream output {};
   document.print (output, "", format_raw);
   return output.str ();
 }
@@ -122,15 +131,15 @@ void changes_clear_notifications_user (string jobid, string username)
 {
   Database_Logs::log (translate ("Start clearing change notifications") + " " + username);
   
-  Database_Modifications database_modifications;
-  Database_Jobs database_jobs;
+  Database_Modifications database_modifications {};
+  Database_Jobs database_jobs {};
 
   // Get the total amount of change notifications to clear for the user.
-  string any_bible = "";
+  string any_bible {};
   vector <int> identifiers = database_modifications.getNotificationIdentifiers (username, any_bible);
   
   // Total notes cleared.
-  int total_cleared = 0;
+  int total_cleared {0};
   
   // Feedback.
   database_jobs.set_percentage (convert_to_int (jobid), 0);
@@ -138,7 +147,7 @@ void changes_clear_notifications_user (string jobid, string username)
 
 
   // The amount of notifications it clears in the next iteration.
-  int cleared_count_in_one_go = 0;
+  int cleared_count_in_one_go {0};
   do {
     cleared_count_in_one_go = database_modifications.clearNotificationsUser (username);
     total_cleared += cleared_count_in_one_go;
