@@ -24,5 +24,5 @@
 void changes_logic_start ();
 const char * changes_personal_category ();
 const char * changes_bible_category ();
-string changes_interlinks (void * webserver_request, string my_url);
-void changes_clear_notifications_user (string jobid, string username);
+std::string changes_interlinks (void * webserver_request, std::string my_url);
+void changes_clear_notifications_user (std::string jobid, std::string username);
