@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,24 +17,17 @@
  */
 
 
-#ifndef INCLUDED_CHECK_FRENCH_H
-#define INCLUDED_CHECK_FRENCH_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+namespace checks_french {
 
-class Checks_French
-{
-public:
-  static void spaceBeforeAfterPunctuation (string bible, int book, int chapter,
-                                           map <int, string> texts);
-  static void citationStyle  (string bible, int book, int chapter,
-                              vector <map <int, string>> verses_paragraphs);
-  static string left_guillemet ();
-  static string right_guillemet ();
-private:
-};
+void space_before_after_punctuation (const std::string & bible, int book, int chapter,
+                                     const std::map <int, std::string> & texts);
+void citation_style  (const std::string & bible, int book, int chapter,
+                      const std::vector <std::map <int, std::string>> & verses_paragraphs);
+std::string left_guillemet ();
+std::string right_guillemet ();
 
-
-#endif
+}
