@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include <webserver/request.h>
 #include <consistency/logic.h>
 #include <database/volatile.h>
+using namespace std;
 
 
 string consistency_poll_url ()
@@ -39,7 +40,7 @@ bool consistency_poll_acl (void * webserver_request)
 
 string consistency_poll (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   int id = convert_to_int (request->query ["id"]);
   Consistency_Logic consistency_logic = Consistency_Logic (webserver_request, id);
   string response = consistency_logic.response ();
