@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/string.h>
 #include <styles/logic.h>
 #include <database/logic.h>
+using namespace std;
 
 
 // Cache values in memory for better speed.
@@ -36,14 +37,14 @@ map <string, string> database_config_bible_cache;
 // The path to the folder for storing the settings for the $bible.
 string Database_Config_Bible::file (string bible)
 {
-  return filter_url_create_root_path (database_logic_databases (), "config", "bible", bible);
+  return filter_url_create_root_path ({database_logic_databases (), "config", "bible", bible});
 }
 
 
 // The path to the file that contains this setting.
 string Database_Config_Bible::file (string bible, const char * key)
 {
-  return filter_url_create_path (file (bible), key);
+  return filter_url_create_path ({file (bible), key});
 }
 
 
@@ -169,6 +170,20 @@ void Database_Config_Bible::setCheckSpaceBeforePunctuation (string bible, bool v
 }
 
 
+const char * space_before_final_note_marker_key ()
+{
+  return "space-before-final-note-marker";
+}
+bool Database_Config_Bible::getCheckSpaceBeforeFinalNoteMarker (string bible)
+{
+  return getBValue (bible, space_before_final_note_marker_key (), false);
+}
+void Database_Config_Bible::setCheckSpaceBeforeFinalNoteMarker (string bible, bool value)
+{
+  setBValue (bible, space_before_final_note_marker_key (), value);
+}
+
+
 bool Database_Config_Bible::getCheckSentenceStructure (string bible)
 {
   return getBValue (bible, "sentence-structure", false);
@@ -379,6 +394,34 @@ void Database_Config_Bible::setCheckFrenchCitationStyle (string bible, bool valu
 }
 
 
+const char * transpose_fix_spaces_notes_key ()
+{
+  return "transpose-fix-spaces-notes";
+}
+bool Database_Config_Bible::getTransposeFixSpacesNotes (string bible)
+{
+  return getBValue (bible, transpose_fix_spaces_notes_key (), false);
+}
+void Database_Config_Bible::setTransposeFixSpacesNotes (string bible, bool value)
+{
+  setBValue (bible, transpose_fix_spaces_notes_key (), value);
+}
+
+
+const char * check_valid_utf8_text_key ()
+{
+  return "check-valid-utf8-text";
+}
+bool Database_Config_Bible::getCheckValidUTF8Text (string bible)
+{
+  return getBValue (bible, check_valid_utf8_text_key (), false);
+}
+void Database_Config_Bible::setCheckValidUTF8Text (string bible, bool value)
+{
+  setBValue (bible, check_valid_utf8_text_key (), value);
+}
+
+
 string Database_Config_Bible::getSprintTaskCompletionCategories (string bible)
 {
   return getValue (bible, "sprint-task-completion-categories", "Translate\nCheck\nHebrew/Greek\nDiscussions");
@@ -529,16 +572,6 @@ void Database_Config_Bible::setVersificationSystem (string bible, string value)
 }
 
 
-string Database_Config_Bible::getVerseMapping (string bible)
-{
-  return getValue (bible, "verse-mapping", english ());
-}
-void Database_Config_Bible::setVerseMapping (string bible, string value)
-{
-  setValue (bible, "verse-mapping", value);
-}
-
-
 bool Database_Config_Bible::getExportWebDuringNight (string bible)
 {
   return getBValue (bible, "export-web-during-night", false);
@@ -559,6 +592,20 @@ void Database_Config_Bible::setExportHtmlDuringNight (string bible, bool value)
 }
 
 
+const char * export_html_notes_on_hover_key ()
+{
+  return "export-html-notes-on-hover";
+}
+bool Database_Config_Bible::getExportHtmlNotesOnHover (string bible)
+{
+  return getBValue (bible, export_html_notes_on_hover_key (), false);
+}
+void Database_Config_Bible::setExportHtmlNotesOnHover (string bible, bool value)
+{
+  setBValue (bible, export_html_notes_on_hover_key (), value);
+}
+
+
 bool Database_Config_Bible::getExportUsfmDuringNight (string bible)
 {
   return getBValue (bible, "export-usfm-during-night", false);
@@ -804,3 +851,44 @@ void Database_Config_Bible::setOdtSpaceAfterVerse (string bible, string value)
   setValue (bible, odt_space_after_verse_key (), value);
 }
 
+
+const char * daily_checks_enabled_key ()
+{
+  return "daily-checks-enabled";
+}
+bool Database_Config_Bible::getDailyChecksEnabled (string bible)
+{
+  return getBValue (bible, daily_checks_enabled_key (), true);
+}
+void Database_Config_Bible::setDailyChecksEnabled (string bible, bool value)
+{
+  setBValue (bible, daily_checks_enabled_key (), value);
+}
+
+
+const char * odt_poetry_verses_left_key ()
+{
+  return "odt-poetry-verses-left";
+}
+bool Database_Config_Bible::getOdtPoetryVersesLeft (string bible)
+{
+  return getBValue (bible, odt_poetry_verses_left_key(), false);
+}
+void Database_Config_Bible::setOdtPoetryVersesLeft (string bible, bool value)
+{
+  setBValue (bible, odt_poetry_verses_left_key(), value);
+}
+
+
+const char * odt_automatic_note_caller_key ()
+{
+  return "odt-automatic-note-caller";
+}
+bool Database_Config_Bible::getOdtAutomaticNoteCaller (string bible)
+{
+  return getBValue (bible, odt_automatic_note_caller_key(), false);
+}
+void Database_Config_Bible::setOdtAutomaticNoteCaller (string bible, bool value)
+{
+  setBValue (bible, odt_automatic_note_caller_key(), value);
+}
