@@ -31,6 +31,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <database/logic.h>
 #include <database/config/general.h>
 #include <locale/logic.h>
+using namespace std;
 
 
 Database_Config_User::Database_Config_User (void * webserver_request_in)
@@ -654,7 +655,7 @@ void Database_Config_User::setSuppressMailFromYourUpdatesNotes (bool value)
 
 vector <string> Database_Config_User::getActiveResources ()
 {
-  if (config_logic_indonesian_cloud_free ()) {
+  if (config::logic::indonesian_cloud_free ()) {
     // In the Indonesian Cloud free, there's one central location for storing the active resources.
     return Database_Config_General::getActiveResources ();
   }
@@ -663,10 +664,10 @@ vector <string> Database_Config_User::getActiveResources ()
 }
 void Database_Config_User::setActiveResources (vector <string> values)
 {
-  if (config_logic_default_bibledit_configuration ()) {
+  if (config::logic::default_bibledit_configuration ()) {
     setList ("active-resources", values);
   }
-  if (config_logic_indonesian_cloud_free ()) {
+  if (config::logic::indonesian_cloud_free ()) {
     Database_Config_General::setActiveResources (values);
   }
 }
@@ -855,7 +856,7 @@ Passage Database_Config_User::getPrintPassageFromForUser (string user)
 }
 void Database_Config_User::setPrintPassageFrom (Passage value)
 {
-  string s = convert_to_string (value.book) + "." + convert_to_string (value.chapter) + "." + value.verse;
+  string s = convert_to_string (value.m_book) + "." + convert_to_string (value.m_chapter) + "." + value.m_verse;
   setValue ("print-passage-from", s);
 }
 
@@ -870,7 +871,7 @@ Passage Database_Config_User::getPrintPassageToForUser (string user)
 }
 void Database_Config_User::setPrintPassageTo (Passage value)
 {
-  string s = convert_to_string (value.book) + "." + convert_to_string (value.chapter) + "." + value.verse;
+  string s = convert_to_string (value.m_book) + "." + convert_to_string (value.m_chapter) + "." + value.m_verse;
   setValue ("print-passage-to", s);
 }
 
@@ -1120,7 +1121,7 @@ int Database_Config_User::getCurrentTheme ()
 {
   // Indonesian Cloud Free
   // Set the "Light" theme as the default theme.
-  if (config_logic_indonesian_cloud_free ()) return getIValue (current_theme_style_key (), 1);
+  if (config::logic::indonesian_cloud_free ()) return getIValue (current_theme_style_key (), 1);
   return getIValue (current_theme_style_key (), 0);
 }
 void Database_Config_User::setCurrentTheme (int index)
