@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/string.h>
 #include <config/globals.h>
 #include <database/sqlite.h>
+using namespace std;
 
 
 // This is the database for the Strong's numbers and English glosses.
@@ -105,9 +106,9 @@ vector <Passage> Database_Kjv::searchStrong (string strong)
   vector <string> verses = result ["verse"];
   for (unsigned int i = 0; i < books.size (); i++) {
     Passage passage;
-    passage.book = convert_to_int (books [i]);
-    passage.chapter = convert_to_int (chapters [i]);
-    passage.verse = verses [i];
+    passage.m_book = convert_to_int (books [i]);
+    passage.m_chapter = convert_to_int (chapters [i]);
+    passage.m_verse = verses [i];
     hits.push_back (passage);
   }
   return hits;
