@@ -24,6 +24,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/date.h>
 #include <database/sqlite.h>
 #include <database/logic.h>
+using namespace std;
 
 
 // Database resilience:
@@ -774,7 +775,7 @@ void Database_Modifications::deleteNotification (int identifier, sqlite3 * db)
   // Make a very short connection to the database, 
   // to prevent corruption when a user deletes lots of changes notifications 
   // by keeping the delete key pressed.
-  bool local_connection = (db == NULL);
+  bool local_connection = (db == nullptr);
   if (local_connection) db = connect ();
   database_sqlite_exec (db, sql.sql);
   if (local_connection) database_sqlite_disconnect (db);
@@ -846,9 +847,9 @@ Passage Database_Modifications::getNotificationPassage (int id)
   vector <string> chapters = result ["chapter"];
   vector <string> verses = result ["verse"];
   for (unsigned int i = 0; i < books.size (); i++) {
-    passage.book = convert_to_int (books [i]);
-    passage.chapter = convert_to_int (chapters [i]);
-    passage.verse = verses [i];
+    passage.m_book = convert_to_int (books [i]);
+    passage.m_chapter = convert_to_int (chapters [i]);
+    passage.m_verse = verses [i];
   }
   return passage;
 }
@@ -945,9 +946,9 @@ vector <int> Database_Modifications::clearNotificationMatches (string username,
   for (auto & personalID : personals) {
     string bible2 = getNotificationBible (personalID);
     Passage passage = getNotificationPassage (personalID);
-    int book = passage.book;
-    int chapter = passage.chapter;
-    int verse = convert_to_int (passage.verse);
+    int book = passage.m_book;
+    int chapter = passage.m_chapter;
+    int verse = convert_to_int (passage.m_verse);
     string modification = getNotificationModification (personalID);
     // Get all matching identifiers from the team's change notifications.
     SqliteSQL sql2 = SqliteSQL ();
