@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,24 +17,18 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_NOTEASSIGNMENT_H
-#define INCLUDED_DATABASE_NOTEASSIGNMENT_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Database_NoteAssignment
 {
 public:
-  bool exists (string user);
-  void assignees (string user, vector <string> assignees);
-  vector <string> assignees (string user);
-  bool exists (string user, string assignee);
-  void remove (string user);
+  bool exists (std::string user);
+  void assignees (std::string user, std::vector <std::string> assignees);
+  std::vector <std::string> assignees (std::string user);
+  bool exists (std::string user, std::string assignee);
+  void remove (std::string user);
 private:
-  string path (string user);
+  std::string path (std::string user);
 };
-
-
-#endif
