@@ -22,6 +22,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/string.h>
 #include <database/logs.h>
 #include <database/logic.h>
+using namespace std;
 
 
 /*
@@ -95,12 +96,12 @@ mutex sqlite_execute_mutex;
 
 sqlite3 * database_sqlite_connect_file (string filename)
 {
-  sqlite3 *db;
+  sqlite3 *db {nullptr};
   int rc = sqlite3_open (filename.c_str(), &db);
   if (rc) {
     const char * error = sqlite3_errmsg (db);
-    database_sqlite_error (db, "Database " + filename, (char *) error);
-    return NULL;
+    database_sqlite_error (db, "Database " + filename, const_cast<char*>(error));
+    return nullptr;
   }
   sqlite3_busy_timeout (db, 1000);
   return db;
@@ -139,10 +140,10 @@ string database_sqlite_no_sql_injection (string sql)
 
 void database_sqlite_exec (sqlite3 * db, string sql)
 {
-  char *error = NULL;
+  char *error = nullptr;
   if (db) {
     sqlite_execute_mutex.lock ();
-    int rc = sqlite3_exec (db, sql.c_str(), NULL, NULL, &error);
+    int rc = sqlite3_exec (db, sql.c_str(), nullptr, nullptr, &error);
     sqlite_execute_mutex.unlock ();
     if (rc != SQLITE_OK) database_sqlite_error (db, sql, error);
   } else {
@@ -154,7 +155,7 @@ void database_sqlite_exec (sqlite3 * db, string sql)
 
 map <string, vector <string> > database_sqlite_query (sqlite3 * db, string sql)
 {
-  char * error = NULL;
+  char * error = nullptr;
   SqliteReader reader (0);
   if (db) {
     sqlite_execute_mutex.lock ();
@@ -280,8 +281,8 @@ int SqliteReader::callback (void *userdata, int argc, char **argv, char **column
 {
   SqliteReader * sqlite_reader = static_cast<SqliteReader *> (userdata);
   for (int i = 0; i < argc; i++) {
-    // Handle NULL field.
-    if (argv [i] == NULL) sqlite_reader->result [column_names [i]].push_back ("");
+    // Handle nullptr field.
+    if (argv [i] == nullptr) sqlite_reader->result [column_names [i]].push_back ("");
     else sqlite_reader->result [column_names [i]].push_back (argv[i]);
   }
   return 0;
