@@ -22,6 +22,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/string.h>
 #include <filter/date.h>
 #include <database/sqlite.h>
+using namespace std;
 
 
 // Database resilience: It contains statistical and non-essential data.
@@ -107,7 +108,7 @@ const char * Database_Statistics::name ()
 
 int Database_Statistics::year_ago ()
 {
-  int timestamp = filter_date_seconds_since_epoch ();
+  int timestamp = filter::date::seconds_since_epoch ();
   timestamp -= (3600 * 24 * 365);
   return timestamp;
 }
