@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/string.h>
 #include <database/logic.h>
 #include <database/logic.h>
+using namespace std;
 
 
 // Database resilience: 
@@ -67,22 +68,22 @@ void Database_UserResources::url (const string& name, const string & value)
 // Returns the text fragent for a Bible book with $id.
 string Database_UserResources::book (const string& name, int id)
 {
-  if (id < 1) return "";
-  return load (name, id);
+  if (id < 1) return string();
+  return load (name, static_cast<size_t>(id));
 }
 
 
 // Stores the text fragment for a Bible book in the database.
 void Database_UserResources::book (const string& name, int id, const string & fragment)
 {
-  if (id > 0) save (name, id, fragment);
+  if (id > 0) save (name, static_cast<size_t>(id), fragment);
 }
 
 
 // The folder for storing the user-defined resource definition files.
 string Database_UserResources::folder ()
 {
-  return filter_url_create_root_path (database_logic_databases (), "client");
+  return filter_url_create_root_path ({database_logic_databases (), "client"});
 }
 
 
@@ -96,7 +97,7 @@ string Database_UserResources::fragment ()
 // The full path of the definition file.
 string Database_UserResources::file (const string& name)
 {
-  return filter_url_create_path (folder (), fragment () + filter_url_filename_clean (name));
+  return filter_url_create_path ({folder (), fragment () + filter_url_filename_clean (name)});
 }
 
 
@@ -107,7 +108,7 @@ string Database_UserResources::load (const string & name, size_t offset)
   string path = file (name);
   string contents = filter_url_file_get_contents (path);
   vector <string> lines = filter_string_explode (contents, '\n');
-  if (offset >= lines.size ()) return "";
+  if (offset >= lines.size ()) return string();
   return lines [offset];
 }
 
