@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,37 +17,31 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_VERSIFICATIONS_H
-#define INCLUDED_DATABASE_VERSIFICATIONS_H
-
+#pragma once
 
 #include <config/libraries.h>
 #include <filter/passage.h>
 
-
 class Database_Versifications
 {
 public:
   void create ();
   void defaults ();
   void optimize ();
-  void input (const string& contents, const string& name);
-  string output (const string& name);
-  void erase (const string& name);
-  int getID (const string& name);
-  int createSystem (const string& name);
-  vector <string> getSystems ();
-  vector <Passage> getBooksChaptersVerses (const string& name);
-  vector <int> getBooks (const string& name);
-  vector <int> getChapters (const string& name, int book, bool include0 = false);
-  vector <int> getVerses (const string& name, int book, int chapter);
-  vector <int> getMaximumBooks ();
-  vector <int> getMaximumChapters (int book);
-  vector <int> getMaximumVerses (int book, int chapter);
+  void input (const std::string& contents, const std::string& name);
+  std::string output (const std::string& name);
+  void erase (const std::string& name);
+  int getID (const std::string& name);
+  int createSystem (const std::string& name);
+  std::vector <std::string> getSystems ();
+  std::vector <Passage> getBooksChaptersVerses (const std::string& name);
+  std::vector <int> getBooks (const std::string& name);
+  std::vector <int> getChapters (const std::string& name, int book, bool include0 = false);
+  std::vector <int> getVerses (const std::string& name, int book, int chapter);
+  std::vector <int> getMaximumBooks ();
+  std::vector <int> getMaximumChapters (int book);
+  std::vector <int> getMaximumVerses (int book, int chapter);
 private:
   sqlite3 * connect ();
   bool creating_defaults = false;
 };
-
-
-#endif
