@@ -24,11 +24,13 @@
 class Dialog_Color
 {
 public:
-  Dialog_Color (string url, string question);
+  Dialog_Color (std::string url, std::string question);
   ~Dialog_Color ();
-  void add_query (string parameter, string value);
-  string run ();
+  Dialog_Color(const Dialog_Color&) = delete;
+  Dialog_Color operator=(const Dialog_Color&) = delete;
+  void add_query (std::string parameter, std::string value);
+  std::string run ();
 private:
-  void * assets_view = NULL;
-  string base_url;
+  void * assets_view {nullptr};
+  std::string base_url {};
 };
