@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string edit_edit_url ();
+std::string edit_edit_url ();
 bool edit_edit_acl (void * webserver_request);
-string edit_edit (void * webserver_request);
+std::string edit_edit (void * webserver_request);
