@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include <database/logs.h>
 #include <quill/logic.h>
 #include <database/config/bible.h>
+using namespace std;
 
 
 string edit_load_url ()
@@ -41,15 +42,14 @@ string edit_load_url ()
 bool edit_load_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  bool read, write;
-  access_a_bible (webserver_request, read, write);
+  auto [ read, write ] = access_bible::any (webserver_request);
   return write;
 }
 
 
 string edit_load (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
   string bible = request->query ["bible"];
   int book = convert_to_int (request->query ["book"]);
@@ -57,7 +57,7 @@ string edit_load (void * webserver_request)
   string unique_id = request->query ["id"];
 
   // Store a copy of the USFM loaded in the editor for later reference.
-  storeLoadedUsfm (webserver_request, bible, book, chapter, unique_id);
+  storeLoadedUsfm2 (webserver_request, bible, book, chapter, unique_id);
   
   string stylesheet = Database_Config_Bible::getEditorStylesheet (bible);
   
@@ -71,14 +71,14 @@ string edit_load (void * webserver_request)
   string html = editor_usfm2html.get ();
   
   // To make editing empty verses easier, convert spaces to non-breaking spaces, so they appear in the editor.
-  if (usfm_contains_empty_verses (usfm)) {
+  if (filter::usfm::contains_empty_verses (usfm)) {
     string search = "<span> </span>";
     string replace = "<span>" + unicode_non_breaking_space_entity () + "</span>";
     html = filter_string_str_replace (search, replace, html);
   }
   
   string user = request->session_logic ()->currentUser ();
-  bool write = access_bible_book_write (webserver_request, user, bible, book);
+  bool write = access_bible::book_write (webserver_request, user, bible, book);
   
-  return Checksum_Logic::send (html, write);
+  return checksum_logic::send (html, write);
 }
