@@ -26,6 +26,7 @@
 #include <editor/usfm2html.h>
 #include <access/bible.h>
 #include <database/config/bible.h>
+using namespace std;
 
 
 string edit_navigate_url ()
@@ -37,7 +38,7 @@ string edit_navigate_url ()
 bool edit_navigate_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  auto [ read, write ] = AccessBible::Any (webserver_request);
+  auto [ read, write ] = access_bible::any (webserver_request);
   return write;
 }
 
@@ -78,8 +79,8 @@ string edit_navigate (void * webserver_request)
   // Get the number of verses in the USFM.
   // This covers combined verses also.
   int last_offset = 0;
-  vector <int> verses = usfm_get_verse_numbers (usfm);
-  for (int i = 0; i < (int)verses.size (); i++) {
+  vector <int> verses = filter::usfm::get_verse_numbers (usfm);
+  for (int i = 0; i < static_cast<int>(verses.size ()); i++) {
     if (editor_usfm2html.verseStartOffsets.count (i)) {
       last_offset = editor_usfm2html.verseStartOffsets [i];
     } else {
@@ -114,9 +115,9 @@ string edit_navigate (void * webserver_request)
   int verse = Ipc_Focus::getVerse (request);
   for (size_t i = 0; i < verses.size (); i++) {
     if (verse == verses[i]) {
-      if ((size_t) offset >= starting_offsets [i]) {
-        if ((size_t) offset <= ending_offsets [i]) {
-          return "";
+      if (offset >= starting_offsets [i]) {
+        if (offset <= ending_offsets [i]) {
+          return string();
         }
       }
     }
