@@ -24,6 +24,7 @@
 #include <webserver/request.h>
 #include <editor/styles.h>
 #include <access/bible.h>
+using namespace std;
 
 
 string edit_styles_url ()
@@ -35,7 +36,7 @@ string edit_styles_url ()
 bool edit_styles_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  auto [ read, write ] = AccessBible::Any (webserver_request);
+  auto [ read, write ] = access_bible::any (webserver_request);
   return read;
 }
 
