@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_EDITONE2_LOAD_H
-#define INCLUDED_EDITONE2_LOAD_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string editone2_load_url ();
+std::string editone2_load_url ();
 bool editone2_load_acl (void * webserver_request);
-string editone2_load (void * webserver_request);
-
-
-#endif
+std::string editone2_load (void * webserver_request);
