@@ -34,11 +34,12 @@
 #include <filter/usfm.h>
 #include <locale/translate.h>
 #include <styles/sheets.h>
+using namespace std;
 
 
 void export_esword (string bible, bool log)
 {
-  string directory = filter_url_create_path ({Export_Logic::bibleDirectory (bible), "esword"});
+  string directory = filter_url_create_path ({export_logic::bible_directory (bible), "esword"});
   if (!file_or_dir_exists (directory)) filter_url_mkdir (directory);
   
   
@@ -61,8 +62,6 @@ void export_esword (string bible, bool log)
     vector <int> chapters = database_bibles.getChapters (bible, book);
     for (auto chapter : chapters) {
       string chapter_data = database_bibles.getChapter (bible, book, chapter);
-      chapter_data = usfm_remove_w_attributes (chapter_data);
-      chapter_data = filter_string_trim (chapter_data);
       filter_text_bible.add_usfm_code (chapter_data);
     }
   }
@@ -71,7 +70,7 @@ void export_esword (string bible, bool log)
   filter_text_bible.esword_text->createModule (filename);
 
   
-  Database_State::clearExport (bible, 0, Export_Logic::export_esword);
+  Database_State::clearExport (bible, 0, export_logic::export_esword);
 
   
   if (log) Database_Logs::log (translate("Exported to e-Sword") + " " + bible, Filter_Roles::translator ());
