@@ -37,11 +37,12 @@
 #include <html/header.h>
 #include <locale/translate.h>
 #include <styles/sheets.h>
+using namespace std;
 
 
 void export_web_book (string bible, int book, bool log)
 {
-  string directory = Export_Logic::webDirectory (bible);
+  string directory = export_logic::web_directory (bible);
   if (!file_or_dir_exists (directory)) filter_url_mkdir (directory);
   
   
@@ -56,10 +57,10 @@ void export_web_book (string bible, int book, bool log)
   
   
   // Copy font to the output directory.
-  string font = Fonts_Logic::getTextFont (bible);
+  string font = Fonts_Logic::get_text_font (bible);
   if (!font.empty ()) {
-    if (Fonts_Logic::fontExists (font)) {
-      string fontpath = Fonts_Logic::getFontPath (font);
+    if (Fonts_Logic::font_exists (font)) {
+      string fontpath = Fonts_Logic::get_font_path (font);
       string contents = filter_url_file_get_contents (fontpath);
       fontpath = filter_url_create_path ({directory, font});
       filter_url_file_put_contents (fontpath, contents);
@@ -67,19 +68,19 @@ void export_web_book (string bible, int book, bool log)
   }
   
   
-  string backLinkPath = Export_Logic::webBackLinkDirectory (bible);
+  string backLinkPath = export_logic::web_back_link_directory (bible);
   
   
-  string bibleBookText = bible + " " + Database_Books::getEnglishFromId (book);
+  string bibleBookText = bible + " " + database::books::get_english_from_id (static_cast<book_id>(book));
   
   
   // Web index file for the book.
   Html_Text html_text_rich_book_index (bibleBookText);
   Html_Header htmlHeader = Html_Header (&html_text_rich_book_index);
-  htmlHeader.searchBackLink (backLinkPath + filter_url_html_file_name_bible ("", book), translate("Go back to") + " " + bibleBookText);
+  htmlHeader.search_back_link (backLinkPath + filter_url_html_file_name_bible ("", book), translate("Go back to") + " " + bibleBookText);
   htmlHeader.create ({
     pair (bible, filter_url_html_file_name_bible ()),
-    pair (translate (Database_Books::getEnglishFromId (book)), filter_url_html_file_name_bible ())
+    pair (translate (database::books::get_english_from_id (static_cast<book_id>(book))), filter_url_html_file_name_bible ())
   });
   html_text_rich_book_index.new_paragraph ("navigationbar");
   html_text_rich_book_index.add_text ("|");
@@ -97,8 +98,6 @@ void export_web_book (string bible, int book, bool log)
     
     // Get the USFM for the chapter.
     string usfm = database_bibles.getChapter (bible, book, chapter);
-    // Clean the word level attributes out.
-    usfm = usfm_remove_w_attributes (usfm);
     // Trim it.
     usfm = filter_string_trim (usfm);
     // Use small chunks of USFM at a time for much better performance.
@@ -110,10 +109,10 @@ void export_web_book (string bible, int book, bool log)
     
     // Create breadcrumbs and navigator for the chapter.
     Html_Header html_header = Html_Header (filter_text_chapter.html_text_linked);
-    html_header.searchBackLink (backLinkPath + filter_url_html_file_name_bible ("", book, chapter), translate("Go back to") + " " + bibleBookText + " " + convert_to_string (chapter));
+    html_header.search_back_link (backLinkPath + filter_url_html_file_name_bible ("", book, chapter), translate("Go back to") + " " + bibleBookText + " " + convert_to_string (chapter));
     vector <pair <string, string> > breadcrumbs_navigator;
     breadcrumbs_navigator.push_back (pair (bible, filter_url_html_file_name_bible ()));
-    breadcrumbs_navigator.push_back (pair (translate (Database_Books::getEnglishFromId (book)), filter_url_html_file_name_bible ()));
+    breadcrumbs_navigator.push_back (pair (translate (database::books::get_english_from_id (static_cast<book_id>(book))), filter_url_html_file_name_bible ()));
     if (!is_first_chapter) {
       breadcrumbs_navigator.push_back (pair ("«", filter_url_html_file_name_bible ("", book, chapter - 1)));
     }
@@ -124,7 +123,7 @@ void export_web_book (string bible, int book, bool log)
     // Optionally add a link for giving feedback by email.
     if (!feedback_email.empty ()) {
       breadcrumbs_navigator.push_back (pair ("|", ""));
-      string subject = translate ("Comment on") + " " + bible + " " + Database_Books::getEnglishFromId (book) + " " + convert_to_string (chapter);
+      string subject = translate ("Comment on") + " " + bible + " " + database::books::get_english_from_id (static_cast<book_id>(book)) + " " + convert_to_string (chapter);
       subject = filter_string_str_replace (" ", "%20", subject);
       string link = "mailto:" + feedback_email + "?Subject=" + subject;
       breadcrumbs_navigator.push_back (pair (translate ("Feedback"), link));
@@ -152,17 +151,17 @@ void export_web_book (string bible, int book, bool log)
   
   
   // Clear the flag for this export.
-  Database_State::clearExport (bible, book, Export_Logic::export_web);
+  Database_State::clearExport (bible, book, export_logic::export_web);
   
   
-  if (log) Database_Logs::log (translate("Exported to web") + ": " + bible + " " + Database_Books::getEnglishFromId (book), Filter_Roles::translator ());
+  if (log) Database_Logs::log (translate("Exported to web") + ": " + bible + " " + database::books::get_english_from_id (static_cast<book_id>(book)), Filter_Roles::translator ());
 }
 
 
 void export_web_index (string bible, bool log)
 {
   // Create folders for the web export.
-  string directory = Export_Logic::webDirectory (bible);
+  string directory = export_logic::web_directory (bible);
   if (!file_or_dir_exists (directory)) filter_url_mkdir (directory);
   
   
@@ -183,14 +182,14 @@ void export_web_index (string bible, bool log)
   styles_sheets.create (stylesheet, filecss, false, bible);
   
   
-  string backLinkPath = Export_Logic::webBackLinkDirectory (bible);
+  string backLinkPath = export_logic::web_back_link_directory (bible);
   
   
   // Main index file.
   Html_Text html_text_rich_bible_index (bible);
   // On top are the breadcrumbs, starting with a clickable Bible name.
   Html_Header htmlHeader = Html_Header (&html_text_rich_bible_index);
-  htmlHeader.searchBackLink (backLinkPath + filter_url_html_file_name_bible (), translate("Go back to Bible"));
+  htmlHeader.search_back_link (backLinkPath + filter_url_html_file_name_bible (), translate("Go back to Bible"));
   htmlHeader.create ({ pair (bible, filter_url_html_file_name_bible ())});
   
   
@@ -203,7 +202,7 @@ void export_web_index (string bible, bool log)
   vector <int> books = database_bibles.getBooks (bible);
   for (auto book : books) {
     // Add this book to the main web index.
-    html_text_rich_bible_index.add_link (html_text_rich_bible_index.current_p_node,  filter_url_html_file_name_bible ("", book), "", translate (Database_Books::getEnglishFromId (book)), "", " " + translate (Database_Books::getEnglishFromId (book)) + " ");
+    html_text_rich_bible_index.add_link (html_text_rich_bible_index.current_p_node,  filter_url_html_file_name_bible ("", book), "", translate (database::books::get_english_from_id (static_cast<book_id>(book))), "", " " + translate (database::books::get_english_from_id (static_cast<book_id>(book))) + " ");
     html_text_rich_bible_index.add_text ("|");
   }
   
@@ -221,7 +220,7 @@ void export_web_index (string bible, bool log)
 
   
   // Clear the flag that indicated this export.
-  Database_State::clearExport (bible, 0, Export_Logic::export_web_index);
+  Database_State::clearExport (bible, 0, export_logic::export_web_index);
 
   
   if (log) Database_Logs::log (translate("Exported to web") + ": " + bible + " Index", Filter_Roles::translator ());
