@@ -20,15 +20,28 @@
 #include <filter/merge.h>
 #pragma GCC diagnostic push
 #pragma clang diagnostic ignored "-Wsign-conversion"
+#pragma GCC diagnostic ignored "-Weffc++"
+#pragma GCC diagnostic ignored "-Wold-style-cast"
+#pragma GCC diagnostic ignored "-Wswitch-default"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
 #include <dtl/dtl.hpp>
 #pragma GCC diagnostic pop
-using dtl::Diff3;
 #include <filter/string.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#ifndef HAVE_PUGIXML
 #include <pugixml/pugixml.hpp>
+#endif
+#ifdef HAVE_PUGIXML
+#include <pugixml.hpp>
+#endif
+#pragma GCC diagnostic pop
 #include <email/send.h>
 #include <filter/usfm.h>
-
-
+using namespace std;
+using dtl::Diff3;
 using namespace pugi;
 
 
@@ -255,7 +268,7 @@ string filter_merge_run_clever (string base, string change, string prioritized_c
                                 vector <Merge_Conflict> & conflicts)
 {
   // Get the verse numbers in the changed text.
-  vector <int> verses = usfm_get_verse_numbers (change);
+  vector <int> verses = filter::usfm::get_verse_numbers (change);
   
   vector <string> results;
   
@@ -265,9 +278,9 @@ string filter_merge_run_clever (string base, string change, string prioritized_c
   for (auto verse : verses) {
     
     // Gets the texts to merge for this verse.
-    string base_text = usfm_get_verse_text (base, verse);
-    string change_text = usfm_get_verse_text (change, verse);
-    string prioritized_change_text = usfm_get_verse_text (prioritized_change, verse);
+    string base_text = filter::usfm::get_verse_text (base, verse);
+    string change_text = filter::usfm::get_verse_text (change, verse);
+    string prioritized_change_text = filter::usfm::get_verse_text (prioritized_change, verse);
     
     // Check for combined verses.
     if (change_text == previous_change) continue;
