@@ -33,8 +33,8 @@ public:
   static int admin ();
   static int lowest ();
   static int highest ();
-  static string english (int role);
-  static string text (int role);
+  static std::string english (int role);
+  static std::string text (int role);
   static bool access_control (void * webserver_request, int role);
 private:
 };
