@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,29 +17,23 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_FLATE_FLATE_H
-#define INCLUDED_FLATE_FLATE_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Flate
 {
 public:
-  void set_variable (string key, string value);
-  void enable_zone (string zone);
-  string render (string html);
-  void add_iteration (string key, map <string, string> value);
-  map <string, vector < map <string, string> > > iterations;
+  void set_variable (std::string key, std::string value);
+  void enable_zone (std::string zone);
+  std::string render (std::string html);
+  void add_iteration (std::string key, std::map <std::string, std::string> value);
+  std::map <std::string, std::vector <std::map <std::string, std::string> > > iterations {};
 private:
-  map <string, string> variables;
-  map <string, bool> zones;
-  void process_iterations (string & rendering);
-  void process_zones (string& rendering);
-  void process_variables (string& rendering);
-  void process_translate (string& rendering);
+  std::map <std::string, std::string> variables {};
+  std::map <std::string, bool> zones {};
+  void process_iterations (std::string & rendering);
+  void process_zones (std::string& rendering);
+  void process_variables (std::string& rendering);
+  void process_translate (std::string& rendering);
 };
-
-
-#endif
