@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,17 +17,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_HELP_INDEX_H
-#define INCLUDED_HELP_INDEX_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string help_index_html (const string& url);
-bool help_index_url (const string& url);
+std::string help_index_html (const std::string& url);
+bool help_index_url (const std::string& url);
 bool help_index_acl (void * webserver_request);
-string help_index (void * webserver_request, const string& url);
-
-
-#endif
+std::string help_index (void * webserver_request, const std::string& url);
