@@ -26,10 +26,12 @@ class Html_Header
 {
 public:
   Html_Header (void * html_text);
-  void searchBackLink (string url, string text);
-  void create (const vector <pair <string, string> > & breadcrumbs);
+  Html_Header(const Html_Header&) = delete;
+  Html_Header operator=(const Html_Header&) = delete;
+  void search_back_link (std::string url, std::string text);
+  void create (const std::vector <std::pair <std::string, std::string> > & breadcrumbs);
 private:
-  void * htmlText;
-  string searchBackLinkUrl;
-  string searchBackLinkText;
+  void * m_html_text {nullptr};
+  std::string m_search_back_link_url {};
+  std::string m_search_back_link_text {};
 };
