@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include <access/bible.h>
 #include <tasks/logic.h>
 #include <database/jobs.h>
+using namespace std;
 
 
 string jobs_index_url ()
@@ -45,7 +46,7 @@ bool jobs_index_acl (void * webserver_request)
 
 string jobs_index (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
   string page;
   
@@ -57,12 +58,12 @@ string jobs_index (void * webserver_request)
 
   // Get information about this job.
   Database_Jobs database_jobs = Database_Jobs ();
-  bool exists = database_jobs.idExists (id);
-  int level = database_jobs.getLevel (id);
-  string start = database_jobs.getStart (id);
-  string percentage = database_jobs.getPercentage (id);
-  string progress = database_jobs.getProgress (id);
-  string result = database_jobs.getResult (id);
+  bool exists = database_jobs.id_exists (id);
+  int level = database_jobs.get_level (id);
+  string start = database_jobs.get_start (id);
+  string percentage = database_jobs.get_percentage (id);
+  string progress = database_jobs.get_progress (id);
+  string result = database_jobs.get_result (id);
 
   // Access control for the user.
   int userlevel = request->session_logic()->currentLevel ();
@@ -96,13 +97,13 @@ string jobs_index (void * webserver_request)
     header.refresh (1);
   }
   
-  header.setEditorStylesheet ();
+  header.set_editor_stylesheet ();
 
   page += header.run ();
 
   page += view.render ("jobs", "index");
   
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   
   return page;
 }
