@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-bool journal_logic_filter_entry (const string& entry);
-string journal_logic_filtered_message ();
-string journal_logic_see_journal_for_progress ();
+bool journal_logic_filter_entry (const std::string& entry);
+std::string journal_logic_filtered_message ();
+std::string journal_logic_see_journal_for_progress ();
