@@ -23,6 +23,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/url.h>
 #include <filter/date.h>
 #include <config/globals.h>
+using namespace std;
 
 
 // Takes a month from 1 to 12, and returns its localized name.
@@ -41,17 +42,18 @@ string locale_logic_month (int month)
     case 10: return translate ("October");
     case 11: return translate ("November");
     case 12: return translate ("December");
+    default: translate ("Month") + " " + convert_to_string (month);
   }
-  return translate ("Month") + " " + convert_to_string (month);
+  return string();
 }
 
 
 string locale_logic_date (int seconds)
 {
-  seconds = filter_date_local_seconds (seconds);
-  int day = filter_date_numerical_month_day (seconds);
-  int month = filter_date_numerical_month (seconds);
-  int year = filter_date_numerical_year (seconds);
+  seconds = filter::date::local_seconds (seconds);
+  int day = filter::date::numerical_month_day (seconds);
+  int month = filter::date::numerical_month (seconds);
+  int year = filter::date::numerical_year (seconds);
   return convert_to_string (day) + " " + locale_logic_month (month) + " " + convert_to_string (year);
 }
 
@@ -59,16 +61,16 @@ string locale_logic_date (int seconds)
 string locale_logic_date_time (int seconds)
 {
   // Localize the seconds.
-  seconds = filter_date_local_seconds (seconds);
+  seconds = filter::date::local_seconds (seconds);
   // Convert the seconds into a human readable date and time.
   string timestamp;
   timestamp.append (locale_logic_date (seconds));
   timestamp.append (" ");
-  timestamp.append (filter_string_fill (convert_to_string (filter_date_numerical_hour (seconds)), 2, '0'));
+  timestamp.append (filter_string_fill (convert_to_string (filter::date::numerical_hour (seconds)), 2, '0'));
   timestamp.append (":");
-  timestamp.append (filter_string_fill (convert_to_string (filter_date_numerical_minute (seconds)), 2, '0'));
+  timestamp.append (filter_string_fill (convert_to_string (filter::date::numerical_minute (seconds)), 2, '0'));
   timestamp.append (":");
-  timestamp.append (filter_string_fill (convert_to_string (filter_date_numerical_second (seconds)), 2, '0'));
+  timestamp.append (filter_string_fill (convert_to_string (filter::date::numerical_second (seconds)), 2, '0'));
   // Done.
   return timestamp;
 }
@@ -102,9 +104,9 @@ map <string, string> locale_logic_localizations ()
 }
 
 
-map <string, string> locale_logic_read_po (string file)
+unordered_map <string, string> locale_logic_read_msgid_msgstr (string file)
 {
-  map <string, string> translations;
+  unordered_map <string, string> translations;
   string contents = filter_url_file_get_contents (file);
   vector <string> lines = filter_string_explode (contents, '\n');
   string msgid;
