@@ -23,4 +23,4 @@
 
 const char * manage_hyphenation_url ();
 bool manage_hyphenation_acl (void * webserver_request);
-string manage_hyphenation (void * webserver_request);
+std::string manage_hyphenation (void * webserver_request);
