@@ -42,6 +42,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <session/switch.h>
 #include <ldap/logic.h>
 #include <user/logic.h>
+using namespace std;
 
 
 string manage_users_url ()
@@ -67,7 +68,7 @@ string manage_users (void * webserver_request)
   
   string page;
   Assets_Header header = Assets_Header (translate("Users"), webserver_request);
-  header.addBreadCrumb (menu_logic_settings_menu (), menu_logic_settings_text ());
+  header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
   page = header.run ();
 
   
@@ -86,12 +87,12 @@ string manage_users (void * webserver_request)
   if (request->post.count ("new")) {
     string user = request->post["entry"];
     if (request->database_users ()->usernameExists (user)) {
-      page += Assets_Page::error (translate("User already exists"));
+      page += assets_page::error (translate("User already exists"));
     } else {
       request->database_users ()->add_user(user, user, Filter_Roles::member (), "");
       user_logic_store_account_creation (user);
       user_updated = true;
-      page += Assets_Page::success (translate("User created"));
+      page += assets_page::success (translate("User created"));
     }
   }
   
@@ -108,16 +109,16 @@ string manage_users (void * webserver_request)
     vector <string> users = request->database_users ()->get_users ();
     vector <string> administrators = request->database_users ()->getAdministrators ();
     if (users.size () == 1) {
-      page += Assets_Page::error (translate("Cannot remove the last user"));
+      page += assets_page::error (translate("Cannot remove the last user"));
     } else if ((objectUserLevel >= Filter_Roles::admin ()) && (administrators.size () == 1)) {
-      page += Assets_Page::error (translate("Cannot remove the last administrator"));
-    } else if (config_logic_demo_enabled () && (objectUsername ==  session_admin_credentials ())) {
-      page += Assets_Page::error (translate("Cannot remove the demo admin"));
+      page += assets_page::error (translate("Cannot remove the last administrator"));
+    } else if (config::logic::demo_enabled () && (objectUsername ==  session_admin_credentials ())) {
+      page += assets_page::error (translate("Cannot remove the demo admin"));
     } else {
       string message;
       user_logic_delete_account (objectUsername, role, email, message);
       user_updated = true;
-      page += Assets_Page::success (message);
+      page += assets_page::success (message);
     }
   }
   
@@ -157,11 +158,11 @@ string manage_users (void * webserver_request)
   if (request->post.count ("email")) {
     string email = request->post["entry"];
     if (filter_url_email_is_valid (email)) {
-      page += Assets_Page::success (translate("Email address was updated"));
+      page += assets_page::success (translate("Email address was updated"));
       request->database_users ()->updateUserEmail (objectUsername, email);
       user_updated = true;
     } else {
-      page += Assets_Page::error (translate("The email address is not valid"));
+      page += assets_page::error (translate("The email address is not valid"));
     }
   }
   
@@ -182,7 +183,7 @@ string manage_users (void * webserver_request)
       page += dialog_list.run ();
       return page;
     } else {
-      Assets_Page::success (translate("The user has been granted access to this Bible"));
+      assets_page::success (translate("The user has been granted access to this Bible"));
       // Write access depends on whether it's a translator role or higher.
       bool write = (objectUserLevel >= Filter_Roles::translator ());
       Database_Privileges::setBible (objectUsername, addbible, write);
@@ -198,14 +199,14 @@ string manage_users (void * webserver_request)
     Database_Privileges::removeBibleBook (objectUsername, removebible, 0);
     user_updated = true;
     privileges_updated = true;
-    Assets_Page::success (translate("The user no longer has access to this Bible"));
+    assets_page::success (translate("The user no longer has access to this Bible"));
   }
   
   
   // Enable or disable a user account.
   if (request->query.count ("enable")) {
     request->database_users ()->set_enabled (objectUsername, true);
-    Assets_Page::success (translate("The user account was enabled"));
+    assets_page::success (translate("The user account was enabled"));
   }
   if (request->query.count ("disable")) {
     // Disable the user in the database.
@@ -213,7 +214,7 @@ string manage_users (void * webserver_request)
     // Remove all login tokens (cookies) for this user, so the user no longer is logged in.
     Database_Login::removeTokens (objectUsername);
     // Feedback.
-    Assets_Page::success (translate("The user account was disabled"));
+    assets_page::success (translate("The user account was disabled"));
   }
   
   
@@ -229,7 +230,7 @@ string manage_users (void * webserver_request)
   stringstream tbody;
   bool ldap_on = ldap_logic_is_on ();
   // Retrieve assigned users.
-  vector <string> users = access_user_assignees (webserver_request);
+  vector <string> users = access_user::assignees (webserver_request);
   for (auto & username : users) {
     
     // Gather details for this user account.
@@ -360,13 +361,13 @@ string manage_users (void * webserver_request)
     view.enable_zone ("local");
   }
 
-  if (config_logic_indonesian_cloud_free ()) {
+  if (config::logic::indonesian_cloud_free ()) {
     view.enable_zone("accounts");
   }
 
   page += view.render ("manage", "users");
 
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   
   if (user_updated) notes_logic_maintain_note_assignees (true);
   if (privileges_updated) database_privileges_client_create (objectUsername, true);
