@@ -28,9 +28,18 @@
 #include <webserver/request.h>
 #include <locale/translate.h>
 #include <ipc/focus.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#ifndef HAVE_PUGIXML
 #include <pugixml/pugixml.hpp>
-
-
+#endif
+#ifdef HAVE_PUGIXML
+#include <pugixml.hpp>
+#endif
+#pragma GCC diagnostic pop
+using namespace std;
 using namespace pugi;
 
 
@@ -56,7 +65,7 @@ string Navigation_Passage::get_mouse_navigator (void * webserver_request, string
   
   bool passage_clipped = false;
   
-  bool basic_mode = config_logic_basic_mode (webserver_request);
+  bool basic_mode = config::logic::basic_mode (webserver_request);
   
   xml_document document;
   
@@ -74,7 +83,8 @@ string Navigation_Passage::get_mouse_navigator (void * webserver_request, string
     if (database_navigation.previous_exists (user)) {
       xml_node span_node_back = span_node.append_child("span");
       span_node_back.append_attribute("id") = "navigateback";
-      span_node_back.append_attribute("title") = translate("Back").c_str();
+      string title = translate("Go back or long-press to show history");
+      span_node_back.append_attribute("title") = title.c_str();
       span_node_back.text() = "↶";
     }
   }
@@ -85,7 +95,8 @@ string Navigation_Passage::get_mouse_navigator (void * webserver_request, string
     if (database_navigation.next_exists (user)) {
       xml_node span_node_back = span_node.append_child("span");
       span_node_back.append_attribute("id") = "navigateforward";
-      span_node_back.append_attribute("title") = translate("Forward").c_str();
+      string title = translate("Go forward or long-press to show history");
+      span_node_back.append_attribute("title") = title.c_str();
       span_node_back.text() = "↷";
     }
   }
@@ -102,7 +113,7 @@ string Navigation_Passage::get_mouse_navigator (void * webserver_request, string
     }
   }
   
-  string bookName = Database_Books::getEnglishFromId (book);
+  string bookName = database::books::get_english_from_id (static_cast<book_id>(book));
   bookName = translate (bookName);
 
   {
@@ -142,7 +153,7 @@ string Navigation_Passage::get_mouse_navigator (void * webserver_request, string
   // The verse should exist in the chapter.
   if (bible != "") {
     string usfm = request->database_bibles()->getChapter (bible, book, chapter);
-    vector <int> verses = usfm_get_verse_numbers (usfm);
+    vector <int> verses = filter::usfm::get_verse_numbers (usfm);
     if (!in_array (verse, verses)) {
       if (!verses.empty()) verse = verses [0];
       else verse = 1;
@@ -178,7 +189,7 @@ string Navigation_Passage::get_mouse_navigator (void * webserver_request, string
     a_node.append_attribute("id") = "selectverse";
     a_node.append_attribute("href") = "selectverse";
     a_node.append_attribute("title") = translate("Select verse").c_str();
-    a_node.text() = string (" " + convert_to_string (verse) + " ").c_str();
+    a_node.text() = (" " + convert_to_string (verse) + " ").c_str();
   }
 
   if (next_verse_is_available) {
@@ -209,27 +220,26 @@ string Navigation_Passage::get_mouse_navigator (void * webserver_request, string
 string Navigation_Passage::get_books_fragment (void * webserver_request, string bible)
 {
   Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  int activeBook = Ipc_Focus::getBook (request);
+  book_id active_book = static_cast<book_id>(Ipc_Focus::getBook (request));
   // Take standard books in case of no Bible.
-  vector <int> books;
-  if (bible == "") {
-    books = Database_Books::getIDs ();
+  vector <book_id> books;
+  if (bible.empty()) {
+    books = database::books::get_ids ();
   } else {
-    books = filter_passage_get_ordered_books (bible);
+    vector <int> book_numbers = filter_passage_get_ordered_books (bible);
+    for (auto book_number : book_numbers) books.push_back (static_cast<book_id>(book_number));
   }
-  string html;
+  string html {};
   for (auto book : books) {
-    string bookName = Database_Books::getEnglishFromId (book);
-    bookName = translate (bookName);
-    bool selected = (book == activeBook);
-    string bookType = Database_Books::getType (book);
-    add_selector_link (html, convert_to_string (book), "applybook", bookName, selected, bookType);
+    string book_name = database::books::get_english_from_id (book);
+    book_name = translate (book_name);
+    bool selected = (book == active_book);
+    string book_type = database::books::book_type_to_string (database::books::get_type (book));
+    add_selector_link (html, convert_to_string (static_cast<int>(book)), "applybook", book_name, selected, book_type);
   }
   add_selector_link (html, "cancel", "applybook", "[" + translate ("cancel") + "]", false, "");
-
   html.insert (0, "<span id='applybook'>" + translate ("Select book") + ": ");
   html.append ("</span>");
-
   return html;
 }
 
@@ -267,7 +277,7 @@ string Navigation_Passage::get_verses_fragment (void * webserver_request, string
     Database_Versifications database_versifications;
     verses = database_versifications.getVerses (english (), book, chapter);
   } else {
-    verses = usfm_get_verse_numbers (request->database_bibles()->getChapter (bible, book, chapter));
+    verses = filter::usfm::get_verse_numbers (request->database_bibles()->getChapter (bible, book, chapter));
   }
   string html;
   html.append (" ");
@@ -334,9 +344,9 @@ void Navigation_Passage::set_passage (void * webserver_request, string bible, st
     Passage inputpassage = Passage ("", currentBook, currentChapter, convert_to_string (currentVerse));
     passage_to_set = filter_passage_interpret_passage (inputpassage, passage);
   }
-  if (passage_to_set.book != 0) {
-    Ipc_Focus::set (webserver_request, passage_to_set.book, passage_to_set.chapter, convert_to_int (passage_to_set.verse));
-    Navigation_Passage::record_history (webserver_request, passage_to_set.book, passage_to_set.chapter, convert_to_int (passage_to_set.verse));
+  if (passage_to_set.m_book != 0) {
+    Ipc_Focus::set (webserver_request, passage_to_set.m_book, passage_to_set.m_chapter, convert_to_int (passage_to_set.m_verse));
+    Navigation_Passage::record_history (webserver_request, passage_to_set.m_book, passage_to_set.m_chapter, convert_to_int (passage_to_set.m_verse));
   }
 }
 
@@ -376,9 +386,9 @@ void Navigation_Passage::goto_next_chapter (void * webserver_request, string bib
   int currentBook = Ipc_Focus::getBook (webserver_request);
   int currentChapter = Ipc_Focus::getChapter (webserver_request);
   Passage passage = Navigation_Passage::get_next_chapter (webserver_request, bible, currentBook, currentChapter);
-  if (passage.book != 0) {
-    Ipc_Focus::set (webserver_request, passage.book, passage.chapter, convert_to_int (passage.verse));
-    Navigation_Passage::record_history (webserver_request, passage.book, passage.chapter, convert_to_int (passage.verse));
+  if (passage.m_book != 0) {
+    Ipc_Focus::set (webserver_request, passage.m_book, passage.m_chapter, convert_to_int (passage.m_verse));
+    Navigation_Passage::record_history (webserver_request, passage.m_book, passage.m_chapter, convert_to_int (passage.m_verse));
   }
 }
 
@@ -388,9 +398,9 @@ void Navigation_Passage::goto_previous_chapter (void * webserver_request, string
   int currentBook = Ipc_Focus::getBook (webserver_request);
   int currentChapter = Ipc_Focus::getChapter (webserver_request);
   Passage passage = Navigation_Passage::get_previous_chapter (webserver_request, bible, currentBook, currentChapter);
-  if (passage.book != 0) {
-    Ipc_Focus::set (webserver_request, passage.book, passage.chapter, convert_to_int (passage.verse));
-    Navigation_Passage::record_history (webserver_request, passage.book, passage.chapter, convert_to_int (passage.verse));
+  if (passage.m_book != 0) {
+    Ipc_Focus::set (webserver_request, passage.m_book, passage.m_chapter, convert_to_int (passage.m_verse));
+    Navigation_Passage::record_history (webserver_request, passage.m_book, passage.m_chapter, convert_to_int (passage.m_verse));
   }
 }
 
@@ -400,7 +410,7 @@ Passage Navigation_Passage::get_next_verse (void * webserver_request, string bib
   verse++;
   if (bible != "") {
     Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-    vector <int> verses = usfm_get_verse_numbers (request->database_bibles()->getChapter (bible, book, chapter));
+    vector <int> verses = filter::usfm::get_verse_numbers (request->database_bibles()->getChapter (bible, book, chapter));
     if (find (verses.begin(), verses.end(), verse) == verses.end()) {
       if (!verses.empty()) verse = verses.back ();
     }
@@ -415,7 +425,7 @@ Passage Navigation_Passage::get_previous_verse (void * webserver_request, string
   verse--;
   if (bible != "") {
     Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-    vector <int> verses = usfm_get_verse_numbers (request->database_bibles()->getChapter (bible, book, chapter));
+    vector <int> verses = filter::usfm::get_verse_numbers (request->database_bibles()->getChapter (bible, book, chapter));
     if (find (verses.begin(), verses.end(), verse) == verses.end()) {
       if (!verses.empty ()) verse = verses [0];
     }
@@ -431,9 +441,9 @@ void Navigation_Passage::goto_next_verse (void * webserver_request, string bible
   int currentChapter = Ipc_Focus::getChapter (webserver_request);
   int currentVerse = Ipc_Focus::getVerse (webserver_request);
   Passage passage = Navigation_Passage::get_next_verse (webserver_request, bible, currentBook, currentChapter, currentVerse);
-  if (passage.book != 0) {
-    Ipc_Focus::set (webserver_request, passage.book, passage.chapter, convert_to_int (passage.verse));
-    Navigation_Passage::record_history (webserver_request, passage.book, passage.chapter, convert_to_int (passage.verse));
+  if (passage.m_book != 0) {
+    Ipc_Focus::set (webserver_request, passage.m_book, passage.m_chapter, convert_to_int (passage.m_verse));
+    Navigation_Passage::record_history (webserver_request, passage.m_book, passage.m_chapter, convert_to_int (passage.m_verse));
   }
 }
 
@@ -444,9 +454,9 @@ void Navigation_Passage::goto_previous_verse (void * webserver_request, string b
   int currentChapter = Ipc_Focus::getChapter (webserver_request);
   int currentVerse = Ipc_Focus::getVerse (webserver_request);
   Passage passage = Navigation_Passage::get_previous_verse (webserver_request, bible, currentBook, currentChapter, currentVerse);
-  if (passage.book != 0) {
-    Ipc_Focus::set (webserver_request, passage.book, passage.chapter, convert_to_int (passage.verse));
-    Navigation_Passage::record_history (webserver_request, passage.book, passage.chapter, convert_to_int (passage.verse));
+  if (passage.m_book != 0) {
+    Ipc_Focus::set (webserver_request, passage.m_book, passage.m_chapter, convert_to_int (passage.m_verse));
+    Navigation_Passage::record_history (webserver_request, passage.m_book, passage.m_chapter, convert_to_int (passage.m_verse));
   }
 }
 
@@ -466,8 +476,8 @@ void Navigation_Passage::go_back (void * webserver_request)
   Database_Navigation database_navigation;
   string user = request->session_logic()->currentUser ();
   Passage passage = database_navigation.get_previous (user);
-  if (passage.book) {
-    Ipc_Focus::set (webserver_request, passage.book, passage.chapter, convert_to_int (passage.verse));
+  if (passage.m_book) {
+    Ipc_Focus::set (webserver_request, passage.m_book, passage.m_chapter, convert_to_int (passage.m_verse));
   }
 }
 
@@ -478,8 +488,8 @@ void Navigation_Passage::go_forward (void * webserver_request)
   Database_Navigation database_navigation;
   string user = request->session_logic()->currentUser ();
   Passage passage = database_navigation.get_next (user);
-  if (passage.book) {
-    Ipc_Focus::set (webserver_request, passage.book, passage.chapter, convert_to_int (passage.verse));
+  if (passage.m_book) {
+    Ipc_Focus::set (webserver_request, passage.m_book, passage.m_chapter, convert_to_int (passage.m_verse));
   }
 }
 
@@ -499,10 +509,10 @@ void Navigation_Passage::add_selector_link (string& html, string id, string href
   // No wrapping of a book name consisting of more than one word.
   xml_document document;
   xml_node span_node = document.append_child("span");
-  span_node.append_attribute("class") = string("selector" + class_expansion).c_str();
+  span_node.append_attribute("class") = ("selector" + class_expansion).c_str();
   {
     xml_node a_node = span_node.append_child("a");
-    a_node.append_attribute("id") = string (id + "apply").c_str();
+    a_node.append_attribute("id") = (id + "apply").c_str();
     a_node.append_attribute("href") = href.c_str();
     a_node.text() = text.c_str();
   }
@@ -552,7 +562,7 @@ string Navigation_Passage::get_keyboard_navigator (void * webserver_request, str
   // The verse should exist in the chapter.
   if (bible != "") {
     string usfm = request->database_bibles()->getChapter (bible, book, chapter);
-    vector <int> verses = usfm_get_verse_numbers (usfm);
+    vector <int> verses = filter::usfm::get_verse_numbers (usfm);
     if (!in_array (verse, verses)) {
       if (!verses.empty()) verse = verses [0];
       else verse = 1;
@@ -617,7 +627,7 @@ void Navigation_Passage::interpret_keyboard_navigator (void * webserver_request,
   // The verse should exist in the chapter.
   if (bible != "") {
     string usfm = request->database_bibles()->getChapter (bible, book, chapter);
-    vector <int> verses = usfm_get_verse_numbers (usfm);
+    vector <int> verses = filter::usfm::get_verse_numbers (usfm);
     if (!in_array (verse, verses)) {
       if (!verses.empty()) verse = verses [0];
       else verse = 1;
@@ -629,8 +639,8 @@ void Navigation_Passage::interpret_keyboard_navigator (void * webserver_request,
   Passage new_passage = filter_passage_interpret_passage (current_passage, passage);
   
   // Store book / chapter / verse.
-  Ipc_Focus::set (request, new_passage.book, new_passage.chapter, convert_to_int (new_passage.verse));
-  Navigation_Passage::record_history (request, new_passage.book, new_passage.chapter, convert_to_int (new_passage.verse));
+  Ipc_Focus::set (request, new_passage.m_book, new_passage.m_chapter, convert_to_int (new_passage.m_verse));
+  Navigation_Passage::record_history (request, new_passage.m_book, new_passage.m_chapter, convert_to_int (new_passage.m_verse));
 }
 
 
@@ -638,16 +648,16 @@ string Navigation_Passage::get_history_back (void * webserver_request)
 {
   // Get the whole history from the database.
   Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  Database_Navigation database_navigation;
-  string user = request->session_logic()->currentUser ();
+  Database_Navigation database_navigation {};
+  string user {request->session_logic()->currentUser ()};
   vector<Passage> passages = database_navigation.get_history(user, -1);
   // Take the most recent nnn history items and render them.
-  string html;
+  string html {};
   for (size_t i = 0; i < passages.size(); i++) {
     if (i >= 10) continue;
-    string rendering = filter_passage_display(passages[i].book, passages[i].chapter, passages[i].verse);
-    string bookType = Database_Books::getType (passages[i].book);
-    add_selector_link (html, "b" + convert_to_string (i), "applyhistory", rendering, false, bookType);
+    string rendering = filter_passage_display(passages[i].m_book, passages[i].m_chapter, passages[i].m_verse);
+    string book_type = database::books::book_type_to_string (database::books::get_type (static_cast <book_id> (passages[i].m_book)));
+    add_selector_link (html, "b" + convert_to_string (i), "applyhistory", rendering, false, book_type);
   }
   // Add a "cancel" link.
   add_selector_link (html, "cancel", "applyhistory", "[" + translate ("cancel") + "]", false, "");
@@ -664,15 +674,15 @@ string Navigation_Passage::get_history_forward (void * webserver_request)
   // Get the whole history from the database.
   Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Navigation database_navigation;
-  string user = request->session_logic()->currentUser ();
-  vector<Passage> passages = database_navigation.get_history(user, 1);
+  string user {request->session_logic()->currentUser ()};
+  vector<Passage> passages {database_navigation.get_history(user, 1)};
   // Take the most recent nnn history items and render them.
-  string html;
+  string html {};
   for (size_t i = 0; i < passages.size(); i++) {
     if (i >= 10) continue;
-    string rendering = filter_passage_display(passages[i].book, passages[i].chapter, passages[i].verse);
-    string bookType = Database_Books::getType (passages[i].book);
-    add_selector_link (html, "f" + convert_to_string (i), "applyhistory", rendering, false, bookType);
+    string rendering = filter_passage_display(passages[i].m_book, passages[i].m_chapter, passages[i].m_verse);
+    string book_type = database::books::book_type_to_string (database::books::get_type (static_cast<book_id>(passages[i].m_book)));
+    add_selector_link (html, "f" + convert_to_string (i), "applyhistory", rendering, false, book_type);
   }
   // Add a "cancel" link.
   add_selector_link (html, "cancel", "applyhistory", "[" + translate ("cancel") + "]", false, "");
