@@ -32,6 +32,7 @@
 #include <ipc/focus.h>
 #include <navigation/passage.h>
 #include <notes/actions.h>
+using namespace std;
 
 
 string notes_bible_n_url ()
@@ -60,7 +61,7 @@ string notes_bible_n (void * webserver_request)
   
   
   stringstream bibleblock;
-  vector <string> bibles = AccessBible::Bibles (webserver_request);
+  vector <string> bibles = access_bible::bibles (webserver_request);
   bibles.push_back (notes_logic.generalBibleName ());
   for (auto & bible : bibles) {
     bibleblock << "<li><a href=" << quoted("bulk?bible=" + bible) << ">" << bible << "</a></li>" << endl;
@@ -69,6 +70,6 @@ string notes_bible_n (void * webserver_request)
   
   
   page += view.render ("notes", "bb-n");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
