@@ -33,6 +33,7 @@
 #include <ipc/focus.h>
 #include <navigation/passage.h>
 #include <notes/note.h>
+using namespace std;
 
 
 string notes_edit_url ()
@@ -162,6 +163,6 @@ string notes_edit (void * webserver_request)
   
   
   page += view.render ("notes", "edit");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
