@@ -29,6 +29,7 @@
 #include <ipc/notes.h>
 #include <access/logic.h>
 #include <developer/logic.h>
+using namespace std;
 
 
 string notes_poll_url ()
@@ -39,7 +40,7 @@ string notes_poll_url ()
 
 bool notes_poll_acl (void * webserver_request)
 {
-  return access_logic_privilege_view_notes (webserver_request);
+  return access_logic::privilege_view_notes (webserver_request);
 }
 
 
