@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string notes_severity_1_url ();
+std::string notes_severity_1_url ();
 bool notes_severity_1_acl (void * webserver_request);
-string notes_severity_1 (void * webserver_request);
+std::string notes_severity_1 (void * webserver_request);
