@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 #include <access/bible.h>
 #include <ipc/focus.h>
 #include <notes/note.h>
+using namespace std;
 
 
 string notes_summary_url ()
@@ -47,7 +48,7 @@ bool notes_summary_acl (void * webserver_request)
 
 string notes_summary (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Notes database_notes (webserver_request);
   Notes_Logic notes_logic = Notes_Logic (webserver_request);
 
@@ -76,7 +77,7 @@ string notes_summary (void * webserver_request)
   
   page += view.render ("notes", "summary");
   
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   
   return page;
 }
