@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 #include <ipc/focus.h>
 #include <navigation/passage.h>
 #include <notes/actions.h>
+using namespace std;
 
 
 string notes_verses_url ()
@@ -48,7 +49,7 @@ bool notes_verses_acl (void * webserver_request)
 
 string notes_verses (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Notes database_notes (webserver_request);
   Notes_Logic notes_logic = Notes_Logic (webserver_request);
 
@@ -72,7 +73,7 @@ string notes_verses (void * webserver_request)
       line = filter_string_trim (line);
       if (line != "") {
         Passage passage = filter_passage_interpret_passage (previousPassage, line);
-        if (passage.book != 0) {
+        if (passage.m_book != 0) {
           passages.push_back (passage);
           previousPassage = passage;
         }
@@ -95,6 +96,6 @@ string notes_verses (void * webserver_request)
   view.set_variable ("success", success);
   view.set_variable ("error", error);
   page += view.render ("notes", "verses");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
