@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -20,12 +20,13 @@
 #include <public/logic.h>
 #include <webserver/request.h>
 #include <database/config/bible.h>
+using namespace std;
 
 
 vector <string> public_logic_bibles (void * webserver_request)
 {
   vector <string> public_bibles;
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   vector <string> bibles = request->database_bibles ()->getBibles ();
   for (auto & bible : bibles) {
     if (Database_Config_Bible::getPublicFeedbackEnabled (bible)) {
