@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,14 +17,8 @@
 */
 
 
-#ifndef INCLUDED_PUBLIC_LOGIC_H
-#define INCLUDED_PUBLIC_LOGIC_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-vector <string> public_logic_bibles (void * webserver_request);
-
-
-#endif
+std::vector <std::string> public_logic_bibles (void * webserver_request);
