@@ -23,4 +23,4 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 const char * public_login_url ();
 bool public_login_acl (void * webserver_request);
-string public_login (void * webserver_request);
+std::string public_login (void * webserver_request);
