@@ -31,6 +31,7 @@
 #include <assets/page.h>
 #include <locale/translate.h>
 #include <read/index.h>
+using namespace std;
 
 
 string public_new_url ()
@@ -57,7 +58,7 @@ string public_new (void * webserver_request)
     int verse = convert_to_int (request->query ["verse"]);
 
     string chapter_usfm = request->database_bibles()->getChapter (bible, book, chapter);
-    string verse_usfm = usfm_get_verse_text (chapter_usfm, verse);
+    string verse_usfm = filter::usfm::get_verse_text (chapter_usfm, verse);
     string stylesheet = Database_Config_Bible::getExportStylesheet (bible);
     Filter_Text filter_text = Filter_Text (bible);
     filter_text.html_text_standard = new Html_Text (bible);
@@ -69,15 +70,15 @@ string public_new (void * webserver_request)
   
   string page;
   Assets_Header header = Assets_Header (translate ("New feedback"), request);
-  header.setNavigator ();
-  header.setStylesheet ();
+  header.set_navigator ();
+  header.set_stylesheet ();
   page = header.run ();
   Assets_View view;
 
 
   string cancellation_url = "index";
 
-  if (config_logic_indonesian_cloud_free_simple ()) {
+  if (config::logic::indonesian_cloud_free_simple ()) {
     cancellation_url = get_base_url (request) + read_index_url ();
   }
 
@@ -85,6 +86,6 @@ string public_new (void * webserver_request)
 
 
   page += view.render ("public", "new");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
