@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,15 +17,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_QUILL_LOGIC_H
-#define INCLUDED_QUILL_LOGIC_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string quill_logic_class_prefix_block ();
-string quill_logic_class_prefix_inline ();
-
-
-#endif
+std::string quill_logic_class_prefix_block ();
+std::string quill_logic_class_prefix_inline ();
