@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string read_load_url ();
+std::string read_load_url ();
 bool read_load_acl (void * webserver_request);
-string read_load (void * webserver_request);
+std::string read_load (void * webserver_request);
