@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string read_verse_url ();
+std::string read_verse_url ();
 bool read_verse_acl (void * webserver_request);
-string read_verse (void * webserver_request);
+std::string read_verse (void * webserver_request);
