@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 #include <filter/url.h>
 #include <webserver/request.h>
 #include <editone2/index.h>
+using namespace std;
 
 
 string editone_index_url ()
@@ -37,7 +38,11 @@ bool editone_index_acl ()
 
 string editone_index (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
-  redirect_browser (request, editone2_index_url ());
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+  string url = editone2_index_url ();
+  for (auto query : request->query) {
+    url = filter_url_build_http_query (url, query.first, query.second);
+  }
+  redirect_browser (request, url);
   return "";
 }
