@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_RESOURCE_BIBLE2RESOURCE_H
-#define INCLUDED_RESOURCE_BIBLE2RESOURCE_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string resource_bible2resource_url ();
+std::string resource_bible2resource_url ();
 bool resource_bible2resource_acl (void * webserver_request);
-string resource_bible2resource (void * webserver_request);
-
-
-#endif
+std::string resource_bible2resource (void * webserver_request);
