@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string resource_biblegateway_url ();
+std::string resource_biblegateway_url ();
 bool resource_biblegateway_acl (void * webserver_request);
-string resource_biblegateway (void * webserver_request);
+std::string resource_biblegateway (void * webserver_request);
