@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string resource_get_url ();
+std::string resource_get_url ();
 bool resource_get_acl (void * webserver_request);
-string resource_get (void * webserver_request);
+std::string resource_get (void * webserver_request);
