@@ -37,6 +37,7 @@
 #include <menu/logic.h>
 #include <resource/images.h>
 #include <journal/logic.h>
+using namespace std;
 
 
 string resource_image_url ()
@@ -59,8 +60,8 @@ string resource_image (void * webserver_request)
   
   string page;
   Assets_Header header = Assets_Header (translate("Image resources"), request);
-  header.addBreadCrumb (menu_logic_settings_menu (), menu_logic_settings_text ());
-  header.addBreadCrumb (resource_images_url (), menu_logic_resource_images_text ());
+  header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
+  header.add_bread_crumb (resource_images_url (), menu_logic_resource_images_text ());
   page = header.run ();
   Assets_View view;
   string error, success;
@@ -161,6 +162,6 @@ string resource_image (void * webserver_request)
   view.set_variable ("success", success);
   view.set_variable ("error", error);
   page += view.render ("resource", "image");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
