@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include <filter/url.h>
 #include <webserver/request.h>
 #include <database/imageresources.h>
+using namespace std;
 
 
 string resource_imagefetch_url ()
@@ -39,7 +40,7 @@ bool resource_imagefetch_acl (void * webserver_request)
 
 string resource_imagefetch (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
   // Resource and image names.
   string name = request->query ["name"];
