@@ -33,6 +33,7 @@
 #include <journal/index.h>
 #include <dialog/yes.h>
 #include <menu/logic.h>
+using namespace std;
 
 
 string resource_manage_url ()
@@ -54,7 +55,7 @@ string resource_manage (void * webserver_request)
   
   string page;
   Assets_Header header = Assets_Header (translate("USFM Resources"), request);
-  header.addBreadCrumb (menu_logic_settings_menu (), menu_logic_settings_text ());
+  header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
   page = header.run ();
   Assets_View view;
   
@@ -72,7 +73,7 @@ string resource_manage (void * webserver_request)
       page += dialog_yes.run ();
       return page;
     } if (confirm == "yes") {
-      if (AccessBible::Write (request, remove)) {
+      if (access_bible::write (request, remove)) {
         database_usfmresources.deleteResource (remove);
         // The Cloud updates the list of available USFM resources for the clients.
         tasks_logic_queue (LISTUSFMRESOURCES);
@@ -93,7 +94,7 @@ string resource_manage (void * webserver_request)
       page += dialog_yes.run ();
       return page;
     } if (confirm == "yes") {
-      if (AccessBible::Write (request, convert)) {
+      if (access_bible::write (request, convert)) {
         tasks_logic_queue (CONVERTRESOURCE2BIBLE, {convert});
         redirect_browser (request, journal_index_url ());
         return "";
@@ -121,6 +122,6 @@ string resource_manage (void * webserver_request)
 
   
   page += view.render ("resource", "manage");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
