@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string resource_sword_url ();
+std::string resource_sword_url ();
 bool resource_sword_acl (void * webserver_request);
-string resource_sword (void * webserver_request);
+std::string resource_sword (void * webserver_request);
