@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_RESOURCE_UNLOAD_H
-#define INCLUDED_RESOURCE_UNLOAD_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string resource_unload_url ();
+std::string resource_unload_url ();
 bool resource_unload_acl (void * webserver_request);
-string resource_unload (void * webserver_request);
-
-
-#endif
+std::string resource_unload (void * webserver_request);
