@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string resource_user9view_url ();
+std::string resource_user9view_url ();
 bool resource_user9view_acl (void * webserver_request);
-string resource_user9view (void * webserver_request);
+std::string resource_user9view (void * webserver_request);
