@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string search_index_url ();
+std::string search_index_url ();
 bool search_index_acl (void * webserver_request);
-string search_index (void * webserver_request);
+std::string search_index (void * webserver_request);
