@@ -32,6 +32,7 @@
 #include <bb/logic.h>
 #include <search/logic.h>
 #include <access/bible.h>
+using namespace std;
 
 
 string search_replacego_url ()
@@ -43,7 +44,7 @@ string search_replacego_url ()
 bool search_replacego_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  auto [ read, write ] = AccessBible::Any (webserver_request);
+  auto [ read, write ] = access_bible::any (webserver_request);
   return write;
 }
 
@@ -53,7 +54,7 @@ string search_replacego (void * webserver_request)
   Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
   
-  string siteUrl = config_logic_site_url (webserver_request);
+  string siteUrl = config::logic::site_url (webserver_request);
   
   
   // Get the action variables from the query.
@@ -65,20 +66,20 @@ string search_replacego (void * webserver_request)
   
   // Get Bible and passage for this identifier.
   Passage passage = Passage::decode (id);
-  string bible = passage.bible;
-  int book = passage.book;
-  int chapter = passage.chapter;
-  int verse = convert_to_int (passage.verse);
+  string bible = passage.m_bible;
+  int book = passage.m_book;
+  int chapter = passage.m_chapter;
+  int verse = convert_to_int (passage.m_verse);
   
   
   // Check whether the user has write access to the book.
   string user = request->session_logic ()->currentUser ();
-  bool write = AccessBible::BookWrite (webserver_request, user, bible, book);
+  bool write = access_bible::book_write (webserver_request, user, bible, book);
 
   
   // Get the old chapter and verse USFM.
   string old_chapter_usfm = request->database_bibles()->getChapter (bible, book, chapter);
-  string old_verse_usfm = usfm_get_verse_text (old_chapter_usfm, verse);
+  string old_verse_usfm = filter::usfm::get_verse_text (old_chapter_usfm, verse);
 
   
   // As a standard to compare against,
@@ -142,7 +143,7 @@ string search_replacego (void * webserver_request)
   
   // Store the new chapter in the database on success.
   if (replacementOkay && write) {
-    bible_logic_store_chapter (bible, book, chapter, new_chapter_usfm);
+    bible_logic::store_chapter (bible, book, chapter, new_chapter_usfm);
   }
   
   
