@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,19 +17,13 @@
  */
 
 
-#ifndef INCLUDED_SENDRECEIVE_SENDRECEIVE_H
-#define INCLUDED_SENDRECEIVE_SENDRECEIVE_H
-
+#pragma once
 
 #include <config/libraries.h>
 #include <filter/string.hpp>
 
-
-void sendreceive_sendreceive (string bible);
-string sendreceive_sendreceive_sendreceive_text ();
-string sendreceive_sendreceive_send_text ();
-string sendreceive_sendreceive_sendreceive_ready_text ();
-string sendreceive_sendreceive_send_ready_text ();
-
-
-#endif
+void sendreceive_sendreceive (std::string bible);
+std::string sendreceive_sendreceive_sendreceive_text ();
+std::string sendreceive_sendreceive_send_text ();
+std::string sendreceive_sendreceive_sendreceive_ready_text ();
+std::string sendreceive_sendreceive_send_ready_text ();
