@@ -21,7 +21,7 @@
 
 #include <config/libraries.h>
 
-string sendreceive_settings_sendreceive_text ();
-string sendreceive_settings_up_to_date_text ();
+std::string sendreceive_settings_sendreceive_text ();
+std::string sendreceive_settings_up_to_date_text ();
 void sendreceive_settings ();
 void sendreceive_settings_kick_watchdog ();
