@@ -29,19 +29,27 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/indonesian.h>
 #include <confirm/worker.h>
 #include <email/send.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#ifndef HAVE_PUGIXML
 #include <pugixml/pugixml.hpp>
+#endif
+#ifdef HAVE_PUGIXML
+#include <pugixml.hpp>
+#endif
+#pragma GCC diagnostic pop
 #include <tasks/logic.h>
-
-
+using namespace std;
 using namespace pugi;
 
 
-class Verification
+struct Verification
 {
-public:
-  string question;
-  string answer;
-  string passage;
+  string question {};
+  string answer {};
+  string passage {};
 };
 
 
@@ -66,7 +74,7 @@ string session_signup ([[maybe_unused]] void * webserver_request)
   Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
   Assets_Header header = Assets_Header (translate ("Signup"), webserver_request);
-  header.touchCSSOn ();
+  header.touch_css_on ();
   page += header.run ();
   
   Assets_View view;
@@ -237,12 +245,12 @@ string session_signup ([[maybe_unused]] void * webserver_request)
       node = initial_document.append_child ("h3");
       node.text ().set (initial_subject.c_str());
       string information;
-      if (config_logic_default_bibledit_configuration ()) {
+      if (config::logic::default_bibledit_configuration ()) {
         node = initial_document.append_child ("p");
         information = translate("There is a request to open an account with this email address.");
         node.text ().set (information.c_str());
       }
-      if (config_logic_indonesian_cloud_free ()) {
+      if (config::logic::indonesian_cloud_free ()) {
         node = initial_document.append_child ("p");
         information = "Shalom " + user + "!";
         node.text ().set (information.c_str());
@@ -269,10 +277,10 @@ string session_signup ([[maybe_unused]] void * webserver_request)
         initial_body = output.str ();
       }
       string query;
-      if (config_logic_default_bibledit_configuration ()) {
+      if (config::logic::default_bibledit_configuration ()) {
         query = database_users.add_userQuery (user, pass, Filter_Roles::member (), mail);
       }
-      if (config_logic_indonesian_cloud_free ()) {
+      if (config::logic::indonesian_cloud_free ()) {
         // The Indonesian free Cloud new account should have the consultant role for things to work well.
         query = database_users.add_userQuery (user, pass, Filter_Roles::consultant (), mail);
       }
@@ -282,7 +290,7 @@ string session_signup ([[maybe_unused]] void * webserver_request)
       xml_document subsequent_document;
       node = subsequent_document.append_child ("h3");
       node.text ().set (subsequent_subject.c_str());
-      if (config_logic_default_bibledit_configuration ()) {
+      if (config::logic::default_bibledit_configuration ()) {
         node = subsequent_document.append_child ("p");
         information = translate("Welcome!");
         node.text ().set (information.c_str());
@@ -290,7 +298,7 @@ string session_signup ([[maybe_unused]] void * webserver_request)
         information = translate("Your account is now active and you have logged in.");
         node.text ().set (information.c_str());
       }
-      if (config_logic_indonesian_cloud_free ()) {
+      if (config::logic::indonesian_cloud_free ()) {
         node = subsequent_document.append_child ("p");
         information = "Shalom " + user + ",";
         node.text ().set (information.c_str());
@@ -327,7 +335,7 @@ string session_signup ([[maybe_unused]] void * webserver_request)
       }
       // Store the confirmation information in the database.
       confirm_worker.setup (mail, user, initial_subject, initial_body, query, subsequent_subject, subsequent_body);
-      if (config_logic_indonesian_cloud_free ()) {
+      if (config::logic::indonesian_cloud_free ()) {
         // In the Indonesian free Cloud, create the Bible for the user.
         string bible = filter::indonesian::mytranslation (user);
         tasks_logic_queue (CREATEEMPTYBIBLE, {bible});
@@ -342,7 +350,7 @@ string session_signup ([[maybe_unused]] void * webserver_request)
   if (signed_up) page += view.render ("session", "signedup");
   else page += view.render ("session", "signup");
 
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
 
 #endif
 
