@@ -21,12 +21,27 @@
 #include <database/oshb.h>
 #include <filter/string.h>
 #include <filter/passage.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#ifndef HAVE_PUGIXML
 #include <pugixml/pugixml.hpp>
-
-
+#endif
+#ifdef HAVE_PUGIXML
+#include <pugixml.hpp>
+#endif
+#pragma GCC diagnostic pop
+using namespace std;
 using namespace pugi;
 
 
+// Local declarations.
+void sources_morphhb_parse_w_element (Database_OsHb * database_oshb, int book, int chapter, int verse, xml_node node);
+void sources_morphhb_parse_unhandled_node (int book, int chapter, int verse, xml_node node);
+void sources_morphhb_parse ();
+
+
 void sources_morphhb_parse_w_element (Database_OsHb * database_oshb, int book, int chapter, int verse, xml_node node)
 {
   string lemma = node.attribute ("lemma").value ();
