@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string styles_indexm_url ();
+std::string styles_indexm_url ();
 bool styles_indexm_acl (void * webserver_request);
-string styles_indexm (void * webserver_request);
+std::string styles_indexm (void * webserver_request);
