@@ -21,5 +21,5 @@
 
 #include <config/libraries.h>
 
-string sync_mail_url ();
-string sync_mail (void * webserver_request);
+std::string sync_mail_url ();
+std::string sync_mail (void * webserver_request);
