@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,14 +17,9 @@
  */
 
 
-#ifndef INCLUDED_SYNC_SETUP_H
-#define INCLUDED_SYNC_SETUP_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string sync_setup_url ();
-string sync_setup (void * webserver_request);
-
-#endif
+std::string sync_setup_url ();
+std::string sync_setup (void * webserver_request);
