@@ -43,6 +43,7 @@
 #include <email/send.h>
 #include <search/logic.h>
 #include <user/logic.h>
+using namespace std;
 
 
 string system_logic_bibles_file_name ()
@@ -159,16 +160,16 @@ void system_logic_import_bibles_file (string tarball)
     
     // Get details about the USFM to import.
     string stylesheet = styles_logic_standard_sheet ();
-    vector <BookChapterData> book_chapter_text = usfm_import (data, stylesheet);
+    vector <filter::usfm::BookChapterData> book_chapter_text = filter::usfm::usfm_import (data, stylesheet);
     for (auto & book_chapter_data : book_chapter_text) {
-      if (book_chapter_data.book > 0) {
+      if (book_chapter_data.m_book > 0) {
         // Store the data and log it.
         // This does not trigger the client to send it to the Cloud.
         // Reason is that the Cloud is authoritative,
         // so importing outdated Bibles would not affect the authoritative copy in the Cloud.
-        database_bibles.storeChapter (bible, book_chapter_data.book, book_chapter_data.chapter, book_chapter_data.data);
-        string bookname = Database_Books::getEnglishFromId (book_chapter_data.book);
-        Database_Logs::log ("Imported " + bible + " " + bookname + " " + convert_to_string (book_chapter_data.chapter));
+        database_bibles.storeChapter (bible, book_chapter_data.m_book, book_chapter_data.m_chapter, book_chapter_data.m_data);
+        string bookname = database::books::get_english_from_id (static_cast<book_id>(book_chapter_data.m_book));
+        Database_Logs::log ("Imported " + bible + " " + bookname + " " + convert_to_string (book_chapter_data.m_chapter));
       } else {
         // Import error.
         Database_Logs::log ("Could not import this file: " + file);
@@ -515,7 +516,7 @@ void system_logic_indonesian_free_deletion ([[maybe_unused]] string username,
       node = document.append_child ("h3");
       node.text ().set (heading.c_str());
       
-      string explanation = translate ("Inilah hasil terjemahan Saudara:");
+      string explanation = "Inilah hasil terjemahan Saudara:";
       node = document.append_child ("p");
       node.text ().set (explanation.c_str ());
 
