@@ -28,6 +28,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <locale/translate.h>
 #include <assets/header.h>
 #include <menu/logic.h>
+using namespace std;
 
 
 string user_account_url ()
@@ -51,7 +52,7 @@ string user_account ([[maybe_unused]] void * webserver_request)
   Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
 
   Assets_Header header = Assets_Header (translate("Account"), webserver_request);
-  header.addBreadCrumb (menu_logic_settings_menu (), menu_logic_settings_text ());
+  header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
   page = header.run ();
 
   Assets_View view;
@@ -130,7 +131,7 @@ string user_account ([[maybe_unused]] void * webserver_request)
 
   page += view.render ("user", "account");
 
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
 
 #endif
 
