@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string versification_index_url ();
+std::string versification_index_url ();
 bool versification_index_acl (void * webserver_request);
-string versification_index (void * webserver_request);
+std::string versification_index (void * webserver_request);
