@@ -21,8 +21,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include <config/libraries.h>
 
-bool http_parse_header (string header, void * webserver_request);
-void http_parse_post (string content, void * webserver_request);
+bool http_parse_header (std::string header, void * webserver_request);
+void http_parse_post (std::string content, void * webserver_request);
 void http_assemble_response (void * webserver_request);
 void http_stream_file (void * webserver_request, bool enable_cache);
-string http_parse_host (const string & line);
+std::string http_parse_host (const std::string & line);
